@@ -17,7 +17,7 @@
 %                                                                             %
 %                                                                             %
 %                                                                             %
-%  Copyright 1999-2022 ImageMagick Studio LLC, a non-profit organization      %
+%  Copyright @ 2021 ImageMagick Studio LLC, a non-profit organization         %
 %  dedicated to making software imaging solutions freely available.           %
 %                                                                             %
 %  You may not use this file except in compliance with the License.  You may  %
@@ -37,27 +37,38 @@
 %
 */
 
-#include <MagickCore/studio.h>
-#include <MagickCore/artifact.h>
-#include <MagickCore/attribute.h>
-#include <MagickCore/blob.h>
+#include "MagickCore/studio.h"
+#include "MagickCore/annotate.h"
+#include "MagickCore/artifact.h"
+#include "MagickCore/attribute.h"
+#include "MagickCore/blob.h"
 #include "MagickCore/blob-private.h"
-#include <MagickCore/cache.h>
-#include <MagickCore/channel.h>
-#include <MagickCore/colorspace.h>
-#include <MagickCore/exception.h>
+#include "MagickCore/cache.h"
+#include "MagickCore/channel.h"
+#include "MagickCore/color.h"
+#include "MagickCore/color-private.h"
+#include "MagickCore/colorspace.h"
+#include "MagickCore/constitute.h"
+#include "MagickCore/draw.h"
+#include "MagickCore/exception.h"
 #include "MagickCore/exception-private.h"
-#include <MagickCore/image.h>
+#include "MagickCore/geometry.h"
+#include "MagickCore/image.h"
 #include "MagickCore/image-private.h"
-#include <MagickCore/list.h>
-#include <MagickCore/magick.h>
-#include <MagickCore/memory_.h>
-#include <MagickCore/module.h>
-#include <MagickCore/monitor.h>
+#include "MagickCore/list.h"
+#include "MagickCore/magick.h"
+#include "MagickCore/memory_.h"
+#include "MagickCore/module.h"
+#include "MagickCore/monitor.h"
 #include "MagickCore/monitor-private.h"
-#include <MagickCore/pixel-accessor.h>
+#include "MagickCore/option.h"
+#include "MagickCore/pixel-accessor.h"
 #include "MagickCore/quantum-private.h"
-#include <MagickCore/string_.h>
+#include "MagickCore/static.h"
+#include "MagickCore/statistic.h"
+#include "MagickCore/string_.h"
+#include "MagickCore/token.h"
+#include "coders/ftxt.h"
 
 /*
   Define declaractions.
@@ -112,9 +123,9 @@ static MagickBooleanType
 */
 static MagickBooleanType IsFTXT(const unsigned char *magick,const size_t length)
 {
-  if (length < 10)
+  if (length < 7)
     return(MagickFalse);
-  if (LocaleNCompare((char *) magick,"id=ftxt",10) == 0)
+  if (LocaleNCompare((char *) magick,"id=ftxt",7) == 0)
     return(MagickTrue);
   return(MagickFalse);
 }
@@ -752,7 +763,7 @@ static Image *ReadFTXTImage(const ImageInfo *image_info,
 %      size_t RegisterFTXTImage(void)
 %
 */
-ModuleExport unsigned long RegisterFTXTImage(void)
+ModuleExport size_t RegisterFTXTImage(void)
 {
   MagickInfo
     *entry;
@@ -978,7 +989,8 @@ static MagickBooleanType WriteFTXTImage(const ImageInfo *image_info,Image *image
                     FormatLocaleString(buffer,MaxTextExtent,"%s#%Lx",sSep,
                       (signed long long)(((long double)p[i])+0.5));
                   else if (fltHexFmt)
-                    FormatLocaleString(buffer,MaxTextExtent,"%s%a",sSep,p[i]);
+                    FormatLocaleString(buffer,MaxTextExtent,"%s%a",sSep,
+                      (double) p[i]);
                   else
                     FormatLocaleString(buffer,MaxTextExtent,"%s%.*Lg%s",sSep,
                       precision,p[i]*valMult,sSuff);
